pub struct EstimatedRuntime { /* private fields */ }Implementations
Sourceimpl EstimatedRuntime
impl EstimatedRuntime
Sourcepub fn with_min_runtime_secs(self, min_runtime_secs: u64) -> Self
pub fn with_min_runtime_secs(self, min_runtime_secs: u64) -> Self
Sets the estimated runtime in seconds to fund the canister if it is below it.
Sourcepub fn with_fallback_min_cycles(self, fallback_min_cycles: u128) -> Self
pub fn with_fallback_min_cycles(self, fallback_min_cycles: u128) -> Self
Sets the fallback min cycles to trigger the funding operation when the estimated runtime is not available.
Sourcepub fn with_fallback_fund_cycles(self, fallback_fund_cycles: u128) -> Self
pub fn with_fallback_fund_cycles(self, fallback_fund_cycles: u128) -> Self
Sets the fallback cycles to fund the canister with when the estimated runtime is not available.
Sourcepub fn with_fund_runtime_secs(self, fund_runtime_secs: u64) -> Self
pub fn with_fund_runtime_secs(self, fund_runtime_secs: u64) -> Self
Sets the runtime seconds to add to the estimated runtime.
Sourcepub fn with_max_runtime_cycles_fund(self, max_runtime_cycles_fund: u128) -> Self
pub fn with_max_runtime_cycles_fund(self, max_runtime_cycles_fund: u128) -> Self
Sets the maximum cycles to fund the canister with, only used when the estimated runtime is available.
Sourcepub fn min_runtime_secs(&self) -> u64
pub fn min_runtime_secs(&self) -> u64
Get the estimated min runtime in seconds to trigger the funding operation.
Sourcepub fn fund_runtime_secs(&self) -> u64
pub fn fund_runtime_secs(&self) -> u64
Get the runtime seconds to add to the estimated runtime.
Sourcepub fn max_runtime_cycles_fund(&self) -> u128
pub fn max_runtime_cycles_fund(&self) -> u128
Get the maximum cycles to fund the canister with, only used when the estimated runtime is available.
Sourcepub fn fallback_min_cycles(&self) -> u128
pub fn fallback_min_cycles(&self) -> u128
Get the fallback min cycles to trigger the funding operation when the estimated runtime is not available.
Sourcepub fn fallback_fund_cycles(&self) -> u128
pub fn fallback_fund_cycles(&self) -> u128
Get the fallback cycles to fund the canister with when the estimated runtime is not available.